==> simple_sitemap_arbitrary_links-2.1.0.tar.gz: simple_sitemap_arbitrary_links/README.md <==
## INTRODUCTION

Need to add arbitrary URLs to your XML sitemap? The Simple XML sitemap arbitrary links module makes it easy! It provides a simple interface to manage arbitrary links, perfect for SEO without coding.

Features

The Simple XML sitemap arbitrary links module enhances Drupal’s Simple XML Sitemap module by allowing you to:
- Add Arbitrary Links: Include URLs not tied to Drupal entities (e.g., external pages, custom paths).
- User-Friendly Interface: Manage links via a table with fields for URL, priority, change frequency, last modified date, and language.
- AJAX Support: Add new links dynamically without page reloads.
- Unlike core sitemap tools, it supports custom URLs with full control over sitemap attributes. Use this module when you need to boost SEO by including non-entity URLs (e.g., marketing landing pages) or multilingual sitemap entries. It’s ideal for site admins who want flexibility without custom development.

## INSTALLATION

Install as you would normally install a contributed Drupal module.
See: https://www.drupal.org/node/895232 for further information.

## CONFIGURATION
1. Go to `/admin/config/search/simplesitemap/custom` (Configuration > Search and metadata > Simple XML Sitemap > Custom Links).
2. You’ll see a table listing existing custom links (if any).
3. Click “Add new link” to insert a blank entry, then edit fields like URL, priority, etc.
4. Keep in mind that you can use different links formats: link, /link, example.com/link. They will be formatted automatically to example.com/link 
5. Save the form to update the database. Check “Regenerate all sitemaps” to refresh `sitemap.xml`.
6. To remove link from database just press Remove button. Don't forget to save with the sitemap regeneration.

## MAINTAINERS

Current maintainers:

- STANISLAV SMIRNOV - https://www.drupal.org/u/stadoom

==> simple_sitemap_arbitrary_links-2.2.0.tar.gz: simple_sitemap_arbitrary_links/README.md <==
## INTRODUCTION

Need to add arbitrary URLs to your XML sitemap? The Simple XML sitemap arbitrary links module makes it easy! It provides a simple interface to manage arbitrary links, perfect for SEO without coding.

Features

The Simple XML sitemap arbitrary links module enhances Drupal’s Simple XML Sitemap module by allowing you to:
- Add Arbitrary Links: Include URLs not tied to Drupal entities (e.g., external pages, custom paths).
- User-Friendly Interface: Manage links via a table with fields for URL, priority, change frequency, last modified date, and language.
- AJAX Support: Add new links dynamically without page reloads.
- Unlike core sitemap tools, it supports custom URLs with full control over sitemap attributes. Use this module when you need to boost SEO by including non-entity URLs (e.g., marketing landing pages) or multilingual sitemap entries. It’s ideal for site admins who want flexibility without custom development.

## INSTALLATION

Install as you would normally install a contributed Drupal module.
See: https://www.drupal.org/node/895232 for further information.

## CONFIGURATION
1. Go to `/admin/config/search/simplesitemap/custom-arbitrary-links` (Configuration > Search and metadata > Simple XML Sitemap > Custom Arbitrary Links).
2. You’ll see a table listing existing custom links (if any).
3. Click “Add new link” to insert a blank entry, then edit fields like URL, priority, etc.
4. Keep in mind that you can use different links formats: link, /link, example.com/link. They will be formatted automatically to example.com/link 
5. Save the form to update the database. Check “Regenerate all sitemaps” to refresh `sitemap.xml`.
6. To remove link from database just press Remove button.

No new content types or text formats are added—just visit the config page to start managing links. Ensure the Simple XML Sitemap module is enabled and configured first.
Add proper permissions to the desired role with "Administer custom sitemap links" permission.

## MAINTAINERS

Current maintainers:

- STANISLAV SMIRNOV - https://www.drupal.org/u/stadoom
